@@ -7,6 +7,7 @@ from .tf2_yolov4.model import YOLOv4
 import json
 import os
 import datetime
+from . import fqcs_constants
 
 CONFIG_FILE = "config.json"
 SAMPLE_LEFT_FILE = "sample_left.jpg"
@@ -65,7 +66,7 @@ def default_err_config():
                 yolo_iou_threshold=0.5,
                 weights="yolov4.h5",
                 yolo_score_threshold=0.3,
-                classes=['dirt'])
+                classes=[fqcs_constants.STAIN, fqcs_constants.EXCESS_GLUE])
 
 
 def default_d_config():
@@ -97,7 +98,7 @@ def default_color_config():
                 beta_l=-150,
                 sat_adj=2,
                 supp_thresh=10,
-                amplify_thresh=(None, None, None),
+                amplify_thresh=(1000, 1000, 1000),
                 amplify_rate=20,
                 max_diff=0.2)
 
@@ -121,7 +122,7 @@ def default_detector_config():
     sim_cfg = default_sim_config()
     detector_config = dict(name="Camera-" + str(datetime.datetime.now()),
                            camera_uri=None,
-                           is_main=True,
+                           is_main=False,
                            is_color_enable=True,
                            is_defect_enable=True,
                            min_width_per=0.1,
@@ -384,7 +385,7 @@ def find_contours_and_box(image: np.ndarray, find_contours_func, d_cfg,
                 and dimB >= min_width and areas[i] >= min_area):
             boxes.append((c, rect, dimA, dimB, box, tl, tr, br, bl, min_x,
                           max_x, center_x))
-    boxes = helper.sort_data_by_loc(boxes, 4)
+    boxes = sorted(boxes, key=lambda x: x[-3])
     return boxes, proc
 
 
@@ -401,7 +402,7 @@ def detect_one_and_size(orig_img: np.ndarray, image: np.ndarray,
     center_x = (min_x + max_x) / 2
     warped = helper.get_warped_box(image, rect, box)
     return (warped, (c, rect, dimA, dimB, box, tl, tr, br, bl, min_x, max_x,
-                     center_x))
+                     center_x), min_x, dimA, dimB)
 
 
 def detect_pair_side_cam(image: np.ndarray, find_contours_func, d_cfg, boxes):
@@ -418,10 +419,10 @@ def detect_pair_side_cam(image: np.ndarray, find_contours_func, d_cfg, boxes):
         min_x = min(cur_min_x, min_x)
         max_x = max(cur_max_x, max_x)
         warped = helper.get_warped_box(image, rect, box)
-        pair.append((warped, box, dimA, dimB))
+        pair.append((warped, box, cur_min_x, dimA, dimB))
 
-    pair = sorted(pair, key=lambda x: x[1][1][0], reverse=True)
-    return pair, image
+    pair = sorted(pair, key=lambda x: x[2])
+    return pair, image, boxes
 
 
 def detect_pair_and_size(image: np.ndarray,
@@ -442,7 +443,7 @@ def detect_pair_and_size(image: np.ndarray,
         min_x = min(cur_min_x, min_x)
         max_x = max(cur_max_x, max_x)
         warped = helper.get_warped_box(image, rect, box)
-        pair.append((warped, box, dimA, dimB))
+        pair.append((warped, box, cur_min_x, dimA, dimB))
 
     center_val = w - max_x - min_x
     is_center = True if (center_val <= stop_condition) else False
@@ -460,8 +461,7 @@ def detect_pair_and_size(image: np.ndarray,
             if (left is not None and right is not None):
                 pair = [left, right]
                 boxes = [left[1], right[1]]
-
-    pair = sorted(pair, key=lambda x: x[1][1][0], reverse=True)
+    pair = sorted(pair, key=lambda x: x[2])
     return pair if len(
         pair) == 2 else None, image, split_left, split_right, boxes
 
